#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "PokktAdsDelegates.h"
#import "PokktUserInfo.h"
#import "PokktAdPlayerViewConfig.h"
#import "PokktAnalyticsDetails.h"
#import "PokktIAPDetails.h"


@interface PokktVideoAds : NSObject

/*!
 @abstract
 Set the PokktVideoAds Delegate
 
 @param videoDelegate video Delegate
 
 @discussion Call this before cache and show video ads. SDK uses this delegate to communicate to your app and notifies the status of ads, such as an ad has been cached or failed, ad watched
 completely or skipped and ad availability status.
 
 */

+ (void)setPokktVideoAdsDelegate: (id <PokktVideoAdsDelegate>)videoDelegate;


/*!
 @abstract
 This method will be used to show rewarded video ad of a particular screenname.
 
 @param screenName Screen name for which ad is requested.
 
 @param viewController The UIViewController in which you will display the ad. Must not be `nil`. This is required so that the ad can present additional view controllers if the user interacts with it.
 */

+(void) showRewarded:(NSString*) screenName withViewController:(UIViewController *) viewController;

/*!
 @abstract
 This method can be used by developer to check if there is any rewarded ad cached for a particular screenName and is available to show.
 
 @param screenName Screen name for which ad is requested.
 */

+(void) checkRewardedAdAvailability:(NSString *)screenName;


/*!
 @abstract
 This method will be used to show non rewarded video ad of a particular screenname.
 
 @param screenName Screen name for which ad is requested.
 
 @param viewController The UIViewController in which you will display the ad. Must not be `nil`. This is required so that the ad can present additional view controllers if the user interacts with it.
 */

+(void) showNonRewarded:(NSString*) screenName withViewController:(UIViewController *) viewController;

/*!
 @abstract
 This method can be used by developer to check if there is any non rewarded ad cached for a particular screenName and is available to show.
 
 @param screenName Screen name for which ad is requested.
 */

+(void) checkNonRewardedAdAvailability:(NSString *)screenName;

@end





@interface PokktInGameAd : NSObject

/*!
 @abstract
 Set the PokktIGADelegate Delegate
 
 @param igaDelegate IGA Delegate
 
 */

+ (void) setIGADelegate:(id<PokktIGADelegate>)igaDelegate;

+ (void) fetchIGAAssets:(NSString*)screenName;

@end

@interface PokktDebugger : NSObject

/*!
 @abstract
 Returns the debug enable status of the POKKT SDK.
 */

+ (BOOL)isDebugEnabled;

/*!
 @abstract
 This method enables/disables the debug logging done by SDK.
 
 by default, logging is off.
 
 @param isDebug true if debug on else false
 */

+ (void)setDebug:(BOOL)isDebug;

/*!
 @abstract
 This is an utility method to show toast.
 
 @param viewController The UIViewController in which you will display the toast message. Must not be `nil`.
 @param message Message to show
 */

+ (void)showToast:(NSString *)message viewController:(UIViewController *)viewController;

@end

@interface PokktAds : NSObject

/*!
 @abstract
 This method is used to set applicationID and security key
 
 @param appId Application Id which you will get from Pokkt dashboard when you create application their.
 
 @param securityKey Security Key which you will get from Pokkt dashboard when you create application their.
 */

+ (void) setPokktConfigWithAppId:(NSString*) appId securityKey:(NSString*) securityKey;

/*!
 @abstract
 This method is used to set extra parameters to POKKT SDK
 
 @param extraParam You can set extra parameters to POKKT  SDK, to be passed back to your server via POKKT server callback. These Extra parameters will be in key-value pair.The key must be alphanumeric value
 
 */

+(void)setCallbackExtraParam:(NSDictionary *)extraParam;

/*!
 @abstract
 This is unique id which will be given to user and generated by developer/publisher.
 Developer/publisher can used this Id to identify their user for the purposes like S2S integration to gratify user
 
 **/

+ (void) setThirdPartyUserId:(NSString*) userId;

// optional parameters
/*!
 @abstract
 This is optional, set user detail like name , age , sex etc.
 
 **/

+ (void)setUserDetails: (PokktUserInfo *)userInfo;

/*!
 @abstract
 Returns the version of the POKKT SDK.
 */

+ (NSString *)getSDKVersion;

/*!
 @abstract
 This function fetch all notification from Pokkt server. All fetched notification will fire on date which you set on POKKT Dashboard.
 
 */

+ (void)callBackgroundTaskCompletedHandler:(void (^)(UIBackgroundFetchResult result))completionHandler;


// optional parameters
/*!
 @abstract
 This is optional, set player detail like skip time, skip message, shouldAllowSkip , skipConfirmMessage etc.
 
 **/

+ (void)setPokktAdPlayerViewConfig: (PokktAdPlayerViewConfig *)adPlayerViewConfig;

+ (void)setPokktAnalyticsDetail:(PokktAnalyticsDetails *)analyticsDetail;

+ (void)trackIAP:(PokktIAPDetails *)inAppPurchaseDetails;

+ (void) updateIGAData:(NSString*)igaAnalyticsData;

@end
