//
//  VideoDemoVC.m
//  SampleApp
//
//  Created by Suraj Singh on 29/09/17.
//  Copyright © 2017 Pokkt. All rights reserved.
//

#import "VideoDemoVC.h"

#define EarnedPoints @"Points"
#define userDefaluts [NSUserDefaults standardUserDefaults]

@interface VideoDemoVC ()
@property (nonatomic) float points;
@end

@implementation VideoDemoVC

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    logoImgV.transform = CGAffineTransformMakeRotation(-M_1_PI);
    
    NSUserDefaults *settings = [NSUserDefaults standardUserDefaults];
    NSString *appId = [settings objectForKey:@"appId"];
    NSString *securityKey = [settings objectForKey:@"secKey"];
    
    /**
     * In [PokktAds setPokktConfig: securityKey:]
     * Replace "AppID" and "SecurityKey"  with the one assigned to you by Pokkt.
     *
     */
    
    [PokktAds setPokktConfigWithAppId:appId securityKey:securityKey];
    
    // optional, set it to true if you want to enable logs for PokktSDK
    
    [PokktDebugger setDebug:YES];
    
    // OPTIONAL but we SUGGEST you to implement delegates as it will help you to determine the status of your request
    
    [PokktVideoAds setPokktVideoAdsDelegate:self];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

    
-(IBAction)showRewardedVideoAd:(id)sender
    {
        [PokktVideoAds showRewarded:screenTF.text withViewController:self];
    }
    
    
-(IBAction)showNonRewardedVideoAd:(id)sender
    {
        [PokktVideoAds showNonRewarded:screenTF.text withViewController:self];
    }
    
#pragma mark Pokkt Video Ads Delegates
    
- (void)videoAdCachingCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded reward: (float)reward
    {
        NSString *msg = [NSString stringWithFormat:@"Video ad caching complete for %@ with reward point is %f",screenName,reward];
        [self showAlertWithMessage:msg];
        
        [self stopSpinner:cacheRewardedVdo];
        [self stopSpinner:cacheNonRewardedVdo];
    }
    
- (void)videoAdCachingFailed: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
    {
        NSString *msg = [NSString stringWithFormat:@"Video ad caching failed for %@ with error is %@",screenName,errorMessage];
        [self showAlertWithMessage:msg];
        [self stopSpinner:cacheRewardedVdo];
        [self stopSpinner:cacheNonRewardedVdo];
    }
    
- (void)videoAdCompleted: (NSString *)screenName isRewarded: (BOOL)isRewarded
    {
        NSString *msg = [NSString stringWithFormat:@"Video ad complete for %@",screenName];
        
        [self showAlertWithMessage:msg];
    }
    
- (void)videoAdDisplayed: (NSString *)screenName isRewarded: (BOOL)isRewarded
    {
        NSString *msg = [NSString stringWithFormat:@"Video ad displayed for %@",screenName];
        [self showAlertWithMessage:msg];
    }
    
- (void)videoAdGratified: (NSString *)screenName reward:(float)reward
    {
        
        if([userDefaluts objectForKey:EarnedPoints])
        {
            self.points = [[userDefaluts objectForKey:EarnedPoints] floatValue];
        }
        if (reward > 0)
        {
            self.points += reward;
            [userDefaluts setValue:[NSString stringWithFormat:@"%f",self.points] forKey:EarnedPoints];
            [userDefaluts synchronize];
            [self updateEarnedPoints];
        }
        
        NSString *msg = [NSString stringWithFormat:@"Video ad gratified for %@ with reward is %f",screenName,reward];
        [self showAlertWithMessage:msg];
    }
    
- (void)videoAdSkipped: (NSString *)screenName isRewarded: (BOOL)isRewarded
    {
        NSString *msg = [NSString stringWithFormat:@"Video ad skipper for %@",screenName];
        [self showAlertWithMessage:msg];
    }
    
- (void)videoAdClosed:(NSString *)screenName isRewarded: (BOOL)isRewarded
    {
        NSString *msg = [NSString stringWithFormat:@"Video ad closed for %@",screenName];
        [self showAlertWithMessage:msg];
    }
    
- (void)videoAdAvailabilityStatus: (NSString *)screenName isRewarded: (BOOL)isRewarded isAdAvailable: (BOOL)isAdAvailable
    {
        NSString *statusString = @"is available";
        if (!isAdAvailable) {
            statusString = @"is not available";
        }
        if (isAdAvailable) {
            
        }
        NSString *msg = [NSString stringWithFormat:@"Video ad %@ for %@",statusString,screenName];
        [self showAlertWithMessage:msg];
    }
    
- (void)videoAdFailedToShow: (NSString *)screenName isRewarded: (BOOL)isRewarded errorMessage: (NSString *)errorMessage
    {
        NSString *msg = [NSString stringWithFormat:@"Video ad falied to show for %@",screenName];
        [self showAlertWithMessage:msg];
    }
    
#pragma mark set up UI elements
    
- (void)updateEarnedPoints
    {
        if([userDefaluts objectForKey:EarnedPoints])
        {
            self.points = [[userDefaluts objectForKey:EarnedPoints] floatValue];
            earnedPointLbl.text = [NSString stringWithFormat:@"Earned Points: %.02f",self.points];
        }
    }
    
-(void)showAlertWithMessage:(NSString *)msg
{
   
}

- (void)pressesBegan:(NSSet<UIPress *> *)presses withEvent:(UIPressesEvent *)event
{
    
}
    
-(void)addSpinnerOnButton:(UIButton *)button
    {
        UIControl *layer  = [[UIControl alloc] initWithFrame:CGRectMake(0, 0, button.frame.size.width, button.frame.size.height)];
        [layer setTag:button.tag+2000];
        [layer setBackgroundColor:[UIColor colorWithRed:0.0 green:0.0 blue:0.0 alpha:0.5]];
        [button addSubview:layer];
        
        UIActivityIndicatorView *activityIndicator = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleWhiteLarge];
        activityIndicator.alpha = 1.0;
        activityIndicator.tag = button.tag + 1000;
        [button addSubview:activityIndicator];
        activityIndicator.center = CGPointMake(button.frame.size.width/2, button.frame.size.height/2);
        [activityIndicator startAnimating];
    }
    
-(void)stopSpinner:(UIButton *)button
    {
        UIActivityIndicatorView *spinner = [button viewWithTag:button.tag+1000];
        
        if (spinner != nil)
        {
            [spinner stopAnimating];
            [spinner removeFromSuperview];
            spinner = nil;
        }
        
        UIControl *layer = (UIControl *)[button viewWithTag:button.tag+2000];
        
        if (layer != nil)
        {
            [layer removeFromSuperview];
            layer = nil;
        }
    }

@end
